#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from typing import Optional

from PyQt5.QtCore import QCoreApplication, QStandardPaths, QTemporaryDir

from astra_csp_cryptopro.utils import Utils

translate = QCoreApplication.translate


class ApplicationCache:
    def __init__(self):
        self.__common_cache_path = QStandardPaths.writableLocation(
            QStandardPaths.GenericCacheLocation) + '/fly-csp-cryptopro/'
        self.__cache_dir = None  # type: Optional[QTemporaryDir]

    def common_cache_path(self) -> str:
        return self.__common_cache_path

    def cache_path(self) -> str:
        return self.__cache_dir.path()

    def clear_cache(self) -> bool:
        return Utils.delete_directory(self.__common_cache_path)

    def create_dir(self) -> None:
        if not Utils.create_directory(self.__common_cache_path):
            message = translate('text', 'Failed to create directory "{path}"').format(path=self.__common_cache_path)
            raise Exception(message)

        self.__cache_dir = QTemporaryDir(self.__common_cache_path)
        self.__cache_dir.setAutoRemove(False)
        if not self.__cache_dir.isValid():
            message = translate('text', 'Failed to create temporary directory "{path}"').format(
                path=self.__cache_dir.path())
            raise Exception(message)
