#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5.QtCore import QByteArray, Qt
from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QAbstractButton

from astra_csp_cryptopro.cprocsp_process import CprocspProcess
from astra_csp_cryptopro.interactive_process_dialog import InteractiveProcessDialog


class CprocspProcessDialog(InteractiveProcessDialog):
    __question_key_buttons = {Qt.Key_Y: QDialogButtonBox.Yes,
                              Qt.Key_N: QDialogButtonBox.No,
                              Qt.Key_C: QDialogButtonBox.Cancel}

    __answer_button_keys = {QDialogButtonBox.Yes: QByteArray(1, 'Y'),
                            QDialogButtonBox.No: QByteArray(1, 'N'),
                            QDialogButtonBox.Cancel: QByteArray(1, 'C')}

    def __init__(self, process: CprocspProcess, parent: QWidget = None) -> None:
        super().__init__(process=process, parent=parent)
        self.__setup()

    def __setup(self) -> None:
        self.answersButtonBox.clicked.connect(self.__on_buttonbox_clicked)
        self._process.readyReadStandardOutput.connect(self.__on_process_ready_read_standard_output)

    def __on_process_ready_read_standard_output(self) -> None:
        output = self._process.output()
        if len(output) > 0:
            self.waitLabel.setVisible(False)
            self.textEdit.setVisible(True)
        else:
            self.waitLabel.setVisible(True)
            self.textEdit.setVisible(False)

        self.textEdit.setText(output)
        self.__check_question_keys()

    def __check_question_keys(self) -> None:
        buttons = QDialogButtonBox.StandardButtons()
        keys = self._process.question_keys(self._process.last_standard_output)
        for key in keys:
            if key in self.__question_key_buttons:
                buttons |= self.__question_key_buttons[key]

        self.answersButtonBox.setStandardButtons(buttons)

    def __on_buttonbox_clicked(self, button: QAbstractButton) -> None:
        key = self.answersButtonBox.standardButton(button)
        if key in self.__answer_button_keys.keys():
            self._process.write(self.__answer_button_keys[key])
            self.answersButtonBox.setStandardButtons(QDialogButtonBox.StandardButtons())
