#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5.QtCore import QDir

from astra_csp_cryptopro.cprocsp_process import CprocspProcess


class CreateFileSignatureProcess(CprocspProcess):
    def __init__(self, bin_dir: QDir) -> None:
        super().__init__(bin_dir=bin_dir)
        self.__document = ''
        self.__signature = ''
        self.__setup()

    @property
    def document(self) -> str:
        return self.__document

    @property
    def signature(self) -> str:
        return self.__signature

    def __setup(self) -> None:
        self.set_bin_name('cryptcp')

    def setup_arguments(self, file_path: str, sig_name: str, fingerprint: str,
                        der_format: bool = False, time_address: str = None) -> None:
        arguments = ['-sign', '-thumbprint', fingerprint]
        if der_format:
            arguments.append('-der')
        if time_address:
            arguments.extend(['-cadest', '-cadesTSA', time_address])
        arguments.extend(['-detached', file_path, sig_name])
        self.setArguments(arguments)
        self.__document = file_path
        self.__signature = sig_name
