#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from PyQt5.QtGui import QCloseEvent
from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QAbstractButton

from astra_csp_cryptopro.process import Process, CompletedResult
from astra_csp_cryptopro.wait_dialog import WaitDialog


class InteractiveProcessDialog(WaitDialog):
    def __init__(self, process: Process, parent: QWidget = None) -> None:
        super().__init__(parent=parent)
        self._process = process
        self.__setup()

    def __setup(self) -> None:
        self.setWindowTitle(self._process.command)
        self._process.finished.connect(self.__on_process_completed)
        self.mainButtonBox.clicked.connect(self.__on_buttonbox_clicked)

        self.adjustSize()

    def __on_process_completed(self, _: CompletedResult) -> None:
        self.close()

    def __on_buttonbox_clicked(self, button: QAbstractButton) -> None:
        buttonbox_button = self.mainButtonBox.standardButton(button)
        if buttonbox_button == QDialogButtonBox.Cancel:
            self._process.terminate()
            self.mainButtonBox.setStandardButtons(QDialogButtonBox.Abort)
        elif buttonbox_button == QDialogButtonBox.Abort:
            self._process.kill()

    # noinspection PyPep8Naming
    def closeEvent(self, _: QCloseEvent) -> None:
        self._cancelled = True
        if QDialogButtonBox.Cancel & self.mainButtonBox.standardButtons():
            self._process.terminate()
            self.mainButtonBox.setStandardButtons(QDialogButtonBox.Abort)
        elif QDialogButtonBox.Abort & self.mainButtonBox.standardButtons():
            self._process.kill()
