#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import importlib
import inspect
import os
from typing import List

from astra_csp_cryptopro.plugins.tab_widget_plugin import TabWidgetPlugin


class PluginLoader:
    def __init__(self) -> None:
        self.__modules = []  # type: List[object]

    def load(self) -> None:
        self.__modules.clear()

        for root, dirs, files in os.walk(
                os.path.dirname(os.path.abspath(__file__)) + '/../../astra_csp_cryptopro_plugins'):
            for dir_name in dirs:
                if os.path.isfile(os.path.join(root, dir_name, dir_name) + '.py'):
                    module = importlib.import_module('astra_csp_cryptopro_plugins.' + dir_name + '.' + dir_name)
                    self.__modules.append(module)
            break

    def tab_plugins(self) -> List[TabWidgetPlugin]:
        plugins = []  # type: List[TabWidgetPlugin]

        for module in self.__modules:
            for element in dir(module):
                obj = getattr(module, element)
                if inspect.isclass(obj):
                    if issubclass(obj, TabWidgetPlugin):
                        plugins.append(obj())

        return plugins
