#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from typing import Optional

from PyQt5 import uic
from PyQt5.QtWidgets import QDialog, QWidget, QLabel, QLineEdit, QDialogButtonBox, QAbstractButton

from astra_csp_cryptopro.utils import Utils

dialog_ui = Utils.file_path('ui', 'interactiveprocess.ui')
UiFormClass, UiFormBase = uic.loadUiType(dialog_ui)  # type: QDialog, QDialog


class WaitDialog(UiFormClass, UiFormBase):
    def __init__(self, parent: QWidget = None) -> None:
        super().__init__(parent=parent)
        self._cancelled = False
        self.waitLabel = None  # type: Optional[QLabel]
        self.textEdit = None  # type: Optional[QLineEdit]
        self.mainButtonBox = None  # type: Optional[QDialogButtonBox]
        self.answersButtonBox = None  # type: Optional[QDialogButtonBox]
        self.setupUi(self)
        self.__setup()

    @property
    def cancelled(self) -> bool:
        return self._cancelled

    def __setup(self) -> None:
        self.setModal(True)
        self.mainButtonBox.clicked.connect(self.__on_buttonbox_clicked)

        self.waitLabel.setVisible(True)
        self.textEdit.setVisible(False)
        self.adjustSize()

    def __on_buttonbox_clicked(self, button: QAbstractButton) -> None:
        if self.mainButtonBox.standardButton(button) == QDialogButtonBox.Cancel:
            self._cancelled = True
